changeset 32002:879456b2022b v9.0.1333

patch 9.0.1333: when redo'ing twice <ScriptCmd> may not get the script ID Commit: https://github.com/vim/vim/commit/6b066c6d8f57aa05f1ab29ab4d098bc4bfabb1bb Author: Bram Moolenaar <Bram@vim.org> Date: Mon Feb 20 18:44:33 2023 +0000 patch 9.0.1333: when redo'ing twice <ScriptCmd> may not get the script ID Problem: When redo'ing twice <ScriptCmd> may not get the script ID. Solution: When "last_used_map" map is not set use "last_used_sid". (closes #11930)
author Bram Moolenaar <Bram@vim.org>
date Mon, 20 Feb 2023 19:45:03 +0100
parents c99521f92536
children aa9c0f0ebfd0
files src/getchar.c src/version.c
diffstat 2 files changed, 16 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -696,6 +696,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1333,
+/**/
     1332,
 /**/
     1331,
--- a/src/getchar.c
+++ b/src/getchar.c
@@ -3974,23 +3974,30 @@ getcmdkeycmd(
 
 #if defined(FEAT_EVAL) || defined(PROTO)
 /*
  * If there was a mapping put info about it in the redo buffer, so that "."
  * will use the same script context.  We only need the SID.
  */
     void
 may_add_last_used_map_to_redobuff(void)
 {
-    char_u buf[3 + 20];
-
-    if (last_used_map == NULL || last_used_map->m_script_ctx.sc_sid < 0)
+    char_u  buf[3 + 20];
+    int	    sid = -1;
+
+    if (last_used_map != NULL)
+	sid = last_used_map->m_script_ctx.sc_sid;
+    if (sid < 0)
+	sid = last_used_sid;
+
+    if (sid < 0)
 	return;
 
     // <K_SID>{nr};
     buf[0] = K_SPECIAL;
     buf[1] = KS_EXTRA;
     buf[2] = KE_SID;
-    vim_snprintf((char *)buf + 3, 20, "%d;",
-					   last_used_map->m_script_ctx.sc_sid);
+    vim_snprintf((char *)buf + 3, 20, "%d;", sid);
     add_buff(&redobuff, buf, -1L);
 }
 #endif
@@ -3974,23 +3974,30 @@ getcmdkeycmd(
 #if defined(FEAT_EVAL) || defined(PROTO)
 /*
- * If there was a mapping put info about it in the redo buffer, so that "."
- * will use the same script context.  We only need the SID.
+ * If there was a mapping we get its SID.  Otherwise, use "last_used_sid", it
+ * is set when redo'ing.
+ * Put this SID in the redo buffer, so that "." will use the same script
+ * context.
  */
     void